# noinspection PyPep8
# noinspection PyArgumentList

"""
AUTO-GENERATED BY `scripts/generate_protocol.py` using `data/browser_protocol.json`
and `data/js_protocol.json` as inputs! Please do not modify this file.
"""

import logging
from typing import Any, Optional, Union

from chromewhip.helpers import PayloadMixin, BaseEvent, ChromeTypeBase

log = logging.getLogger(__name__)

# ServiceName: The Background Service that will be associated with the commands/events.Every Background Service operates independently, but they share the sameAPI.
ServiceName = str

# EventMetadata: A key-value pair for additional event information to pass along.
class EventMetadata(ChromeTypeBase):
    def __init__(self,
                 key: Union['str'],
                 value: Union['str'],
                 ):

        self.key = key
        self.value = value


# BackgroundServiceEvent: 
class BackgroundServiceEvent(ChromeTypeBase):
    def __init__(self,
                 timestamp: Union['Network.TimeSinceEpoch'],
                 origin: Union['str'],
                 serviceWorkerRegistrationId: Union['ServiceWorker.RegistrationID'],
                 service: Union['ServiceName'],
                 eventName: Union['str'],
                 instanceId: Union['str'],
                 eventMetadata: Union['[EventMetadata]'],
                 ):

        self.timestamp = timestamp
        self.origin = origin
        self.serviceWorkerRegistrationId = serviceWorkerRegistrationId
        self.service = service
        self.eventName = eventName
        self.instanceId = instanceId
        self.eventMetadata = eventMetadata


class BackgroundService(PayloadMixin):
    """ Defines events for background web platform features.
    """
    @classmethod
    def startObserving(cls,
                       service: Union['ServiceName'],
                       ):
        """Enables event updates for the service.
        :param service: 
        :type service: ServiceName
        """
        return (
            cls.build_send_payload("startObserving", {
                "service": service,
            }),
            None
        )

    @classmethod
    def stopObserving(cls,
                      service: Union['ServiceName'],
                      ):
        """Disables event updates for the service.
        :param service: 
        :type service: ServiceName
        """
        return (
            cls.build_send_payload("stopObserving", {
                "service": service,
            }),
            None
        )

    @classmethod
    def setRecording(cls,
                     shouldRecord: Union['bool'],
                     service: Union['ServiceName'],
                     ):
        """Set the recording state for the service.
        :param shouldRecord: 
        :type shouldRecord: bool
        :param service: 
        :type service: ServiceName
        """
        return (
            cls.build_send_payload("setRecording", {
                "shouldRecord": shouldRecord,
                "service": service,
            }),
            None
        )

    @classmethod
    def clearEvents(cls,
                    service: Union['ServiceName'],
                    ):
        """Clears all stored data for the service.
        :param service: 
        :type service: ServiceName
        """
        return (
            cls.build_send_payload("clearEvents", {
                "service": service,
            }),
            None
        )



class RecordingStateChangedEvent(BaseEvent):

    js_name = 'Backgroundservice.recordingStateChanged'
    hashable = []
    is_hashable = False

    def __init__(self,
                 isRecording: Union['bool', dict],
                 service: Union['ServiceName', dict],
                 ):
        if isinstance(isRecording, dict):
            isRecording = bool(**isRecording)
        self.isRecording = isRecording
        if isinstance(service, dict):
            service = ServiceName(**service)
        self.service = service

    @classmethod
    def build_hash(cls):
        raise ValueError('Unable to build hash for non-hashable type')


class BackgroundServiceEventReceivedEvent(BaseEvent):

    js_name = 'Backgroundservice.backgroundServiceEventReceived'
    hashable = []
    is_hashable = False

    def __init__(self,
                 backgroundServiceEvent: Union['BackgroundServiceEvent', dict],
                 ):
        if isinstance(backgroundServiceEvent, dict):
            backgroundServiceEvent = BackgroundServiceEvent(**backgroundServiceEvent)
        self.backgroundServiceEvent = backgroundServiceEvent

    @classmethod
    def build_hash(cls):
        raise ValueError('Unable to build hash for non-hashable type')



# noinspection PyPep8
# noinspection PyArgumentList

"""
AUTO-GENERATED BY `scripts/generate_protocol.py` using `data/browser_protocol.json`
and `data/js_protocol.json` as inputs! Please do not modify this file.
"""

import logging
from typing import Any, Optional, Union

from chromewhip.helpers import PayloadMixin, BaseEvent, ChromeTypeBase

log = logging.getLogger(__name__)
from chromewhip.protocol import runtime as Runtime
from chromewhip.protocol import network as Network

# LogEntry: Log entry.
class LogEntry(ChromeTypeBase):
    def __init__(self,
                 source: Union['str'],
                 level: Union['str'],
                 text: Union['str'],
                 timestamp: Union['Runtime.Timestamp'],
                 url: Optional['str'] = None,
                 lineNumber: Optional['int'] = None,
                 stackTrace: Optional['Runtime.StackTrace'] = None,
                 networkRequestId: Optional['Network.RequestId'] = None,
                 workerId: Optional['str'] = None,
                 args: Optional['[Runtime.RemoteObject]'] = None,
                 ):

        self.source = source
        self.level = level
        self.text = text
        self.timestamp = timestamp
        self.url = url
        self.lineNumber = lineNumber
        self.stackTrace = stackTrace
        self.networkRequestId = networkRequestId
        self.workerId = workerId
        self.args = args


# ViolationSetting: Violation configuration setting.
class ViolationSetting(ChromeTypeBase):
    def __init__(self,
                 name: Union['str'],
                 threshold: Union['float'],
                 ):

        self.name = name
        self.threshold = threshold


class Log(PayloadMixin):
    """ Provides access to log entries.
    """
    @classmethod
    def clear(cls):
        """Clears the log.
        """
        return (
            cls.build_send_payload("clear", {
            }),
            None
        )

    @classmethod
    def disable(cls):
        """Disables log domain, prevents further log entries from being reported to the client.
        """
        return (
            cls.build_send_payload("disable", {
            }),
            None
        )

    @classmethod
    def enable(cls):
        """Enables log domain, sends the entries collected so far to the client by means of the
`entryAdded` notification.
        """
        return (
            cls.build_send_payload("enable", {
            }),
            None
        )

    @classmethod
    def startViolationsReport(cls,
                              config: Union['[ViolationSetting]'],
                              ):
        """start violation reporting.
        :param config: Configuration for violations.
        :type config: [ViolationSetting]
        """
        return (
            cls.build_send_payload("startViolationsReport", {
                "config": config,
            }),
            None
        )

    @classmethod
    def stopViolationsReport(cls):
        """Stop violation reporting.
        """
        return (
            cls.build_send_payload("stopViolationsReport", {
            }),
            None
        )



class EntryAddedEvent(BaseEvent):

    js_name = 'Log.entryAdded'
    hashable = []
    is_hashable = False

    def __init__(self,
                 entry: Union['LogEntry', dict],
                 ):
        if isinstance(entry, dict):
            entry = LogEntry(**entry)
        self.entry = entry

    @classmethod
    def build_hash(cls):
        raise ValueError('Unable to build hash for non-hashable type')



# noinspection PyPep8
# noinspection PyArgumentList

"""
AUTO-GENERATED BY `scripts/generate_protocol.py` using `data/browser_protocol.json`
and `data/js_protocol.json` as inputs! Please do not modify this file.
"""

import logging
from typing import Any, Optional, Union

from chromewhip.helpers import PayloadMixin, BaseEvent, ChromeTypeBase

log = logging.getLogger(__name__)

# PressureLevel: Memory pressure level.
PressureLevel = str

# SamplingProfileNode: Heap profile sample.
class SamplingProfileNode(ChromeTypeBase):
    def __init__(self,
                 size: Union['float'],
                 total: Union['float'],
                 stack: Union['[]'],
                 ):

        self.size = size
        self.total = total
        self.stack = stack


# SamplingProfile: Array of heap profile samples.
class SamplingProfile(ChromeTypeBase):
    def __init__(self,
                 samples: Union['[SamplingProfileNode]'],
                 modules: Union['[Module]'],
                 ):

        self.samples = samples
        self.modules = modules


# Module: Executable module information
class Module(ChromeTypeBase):
    def __init__(self,
                 name: Union['str'],
                 uuid: Union['str'],
                 baseAddress: Union['str'],
                 size: Union['float'],
                 ):

        self.name = name
        self.uuid = uuid
        self.baseAddress = baseAddress
        self.size = size


class Memory(PayloadMixin):
    """ 
    """
    @classmethod
    def getDOMCounters(cls):
        """
        """
        return (
            cls.build_send_payload("getDOMCounters", {
            }),
            cls.convert_payload({
                "documents": {
                    "class": int,
                    "optional": False
                },
                "nodes": {
                    "class": int,
                    "optional": False
                },
                "jsEventListeners": {
                    "class": int,
                    "optional": False
                },
            })
        )

    @classmethod
    def prepareForLeakDetection(cls):
        """
        """
        return (
            cls.build_send_payload("prepareForLeakDetection", {
            }),
            None
        )

    @classmethod
    def forciblyPurgeJavaScriptMemory(cls):
        """Simulate OomIntervention by purging V8 memory.
        """
        return (
            cls.build_send_payload("forciblyPurgeJavaScriptMemory", {
            }),
            None
        )

    @classmethod
    def setPressureNotificationsSuppressed(cls,
                                           suppressed: Union['bool'],
                                           ):
        """Enable/disable suppressing memory pressure notifications in all processes.
        :param suppressed: If true, memory pressure notifications will be suppressed.
        :type suppressed: bool
        """
        return (
            cls.build_send_payload("setPressureNotificationsSuppressed", {
                "suppressed": suppressed,
            }),
            None
        )

    @classmethod
    def simulatePressureNotification(cls,
                                     level: Union['PressureLevel'],
                                     ):
        """Simulate a memory pressure notification in all processes.
        :param level: Memory pressure level of the notification.
        :type level: PressureLevel
        """
        return (
            cls.build_send_payload("simulatePressureNotification", {
                "level": level,
            }),
            None
        )

    @classmethod
    def startSampling(cls,
                      samplingInterval: Optional['int'] = None,
                      suppressRandomness: Optional['bool'] = None,
                      ):
        """Start collecting native memory profile.
        :param samplingInterval: Average number of bytes between samples.
        :type samplingInterval: int
        :param suppressRandomness: Do not randomize intervals between samples.
        :type suppressRandomness: bool
        """
        return (
            cls.build_send_payload("startSampling", {
                "samplingInterval": samplingInterval,
                "suppressRandomness": suppressRandomness,
            }),
            None
        )

    @classmethod
    def stopSampling(cls):
        """Stop collecting native memory profile.
        """
        return (
            cls.build_send_payload("stopSampling", {
            }),
            None
        )

    @classmethod
    def getAllTimeSamplingProfile(cls):
        """Retrieve native memory allocations profile
collected since renderer process startup.
        """
        return (
            cls.build_send_payload("getAllTimeSamplingProfile", {
            }),
            cls.convert_payload({
                "profile": {
                    "class": SamplingProfile,
                    "optional": False
                },
            })
        )

    @classmethod
    def getBrowserSamplingProfile(cls):
        """Retrieve native memory allocations profile
collected since browser process startup.
        """
        return (
            cls.build_send_payload("getBrowserSamplingProfile", {
            }),
            cls.convert_payload({
                "profile": {
                    "class": SamplingProfile,
                    "optional": False
                },
            })
        )

    @classmethod
    def getSamplingProfile(cls):
        """Retrieve native memory allocations profile collected since last
`startSampling` call.
        """
        return (
            cls.build_send_payload("getSamplingProfile", {
            }),
            cls.convert_payload({
                "profile": {
                    "class": SamplingProfile,
                    "optional": False
                },
            })
        )

